from .estilos import (
    aplicar_css,
    generate_colors,
    titulo,
    show_warning,
    erro,
    corazul,
    corverde,
    colors_base
)

__all__ = [
    "aplicar_css",
    "generate_colors",
    "titulo",
    "show_warning",
    "erro",
    "corazul",
    "corverde",
    "colors_base"
]
